#!/usr/bin/env python

## Import a list of authentication failures from auth.log
#
# This script will import a set of authentication failures emitted by sshd
# into syslog, typically from the file auth.log.
#
#
# Usage:
#
# $ ./clean_db
# $ ./import_sshd /var/log/auth.log
# $ ./generate_heatmap sshd_map.png
#
# This is released under the terms of the BSD license. See COPYRIGHT for
# further information.
#

import sys
import re

from eventdb import EventDB
from parser import open_logfile, parser_main


## Import authentication failures from sshd into the events database
#
def import_sshd(logfiles, eventsDB = 'events.sqlite'):
    try:
        db = EventDB(eventsDB)

        for filename in logfiles:   
            logfile = open_logfile(filename)

            # sshd[16262]: Failed password for root from 58.211.72.43 port
            # Regular expression to extract the remote host address
            re_ip = re.compile('sshd\[[0-9]+\]: Failed password for .* from (([0-9]+\.){3}[0-9]+) port')

            for line in logfile:
                # Try to grab the IP for the remote host
                matches = re_ip.search(line)
                if matches != None:
                    db.addEvent(matches.group(1))


    except IOError, e:
        print >>sys.stderr, "Could not import log file %s." % filename


## Display usage information
#
def usage(progName):
    print >>sys.stderr, "import_sshd v0.1"
    print >>sys.stderr, "Usage:\n"
    print >>sys.stderr, "  %s [option] ... /var/log/auth.log [logfile2 ...]" % progName
    print >>sys.stderr, ""
    print >>sys.stderr, "  --events-db events.sl3   Use events.sl3 as the source for the heatmap data."
    print >>sys.stderr, ""


## Main entry-point when called as a script
#
def main(argv):
    parser_main(argv, import_sshd, usage)


# If run as a standalone app, behave accordingly.
#
if __name__ == '__main__':
    main(sys.argv)

