import os
import sys
import gzip
import getopt

## Attempt to open a logfile as either gzipped data, or plain text.
#
# This routine will only work with real files if dealing with gzip input, 
# as we rewind the file after doing a test read to ensure it's a gzip file.
#
# @return  Returns either a file or GzipFile object.
#
def open_logfile(filename):
    # Catch the IOError from the initial GzipFile() in case this is not a gzipped log
    try:
        logfile = gzip.GzipFile(filename)
        logfile.readline()
        logfile.seek(0)
    except IOError, e:
        logfile = file(filename)

    return logfile
    

def parser_main(argv, import_routine, usage_routine):
    try:    
        # Parse arguments with getopt
        options, trailer = getopt.getopt(argv[1:], '', ['events-db='])

        # Check for erroneous filenames
        if len(trailer) < 1:
            raise Exception('You must specify at least one log file to parse.')

        fileArgs = {'--events-db': 'eventsDB'}
        args = {}

        # Parse the command-line options
        for option, value in options:
            if option in fileArgs:
                
                # Extract the parameter name
                param = fileArgs[option]
                if not os.path.isfile(value):
                    raise Exception('%s is not a file.' % value)

                args[param] = value
            else:
                raise Exception('Unknown option "%s".' % option)

        import_routine(trailer, **args)

    except Exception, e:
        print >>sys.stderr, "Error: %s" % e.message
        print >>sys.stderr, ""
        usage_routine(argv[0])
        exit(1)


